# update
Summary:		PowerDNS is a Versatile Database Driven Nameserver
Name:			pdns
Version:		3.4.3
Release:		17.2
Epoch:			0
License:		GPL
Group:			System/Servers
URL:			http://www.powerdns.com/
Source0:		http://downloads.powerdns.com/releases/pdns-%{version}.tar.gz

Patch1:                 pdns-slavedb.patch

Source1:		http://downloads.powerdns.com/documentation/html.tar.gz

BuildRequires:		autoconf automake make ragel
BuildRequires:		gcc gcc-c++
BuildRequires:		zlib-devel
BuildRequires:		lua-devel
BuildRequires:          lua-static
BuildRequires:          Percona-Server-devel-51 Percona-Server-shared-51
BuildRequires:		boost-devel

Requires:		lua
Requires:		boost-serialization
Requires:		boost-program-options

Provides:		nameserver pdns-server powerdns = %{version}-%{release}
BuildRoot:		%{_tmppath}/%{name}-%{version}-root

%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

This RPM comes with support for MySQL backend.

%package		tools
Summary:		DNS tools for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		tools
This package contains the DNS tools for the PowerDNS nameserver.

%package		devel
Summary:		Development headers and libraries for %{name}
Group:			System/Servers
Requires:		%{name} = %{version}

%description		devel
Development headers and libraries for %{name}

%prep
%setup -q -n pdns-%{version} -a1
%patch1 -p0

%build
%configure \
    --sysconfdir=%{_sysconfdir}/pdns \
    --libdir=%{_libdir}/%{name} \
    --libdir=%{_libdir} \
    --with-mysql-lib=%{_libdir}/mysql \
    --with-socketdir=/var/run/pdns-server \
    --with-modules="gmysql geo pipe"
#    --enable-static-binaries
%{__make}

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_sysconfdir}/pdns/
install -d $RPM_BUILD_ROOT%{_localstatedir}/run/pdns-server

%{__make} %{?_smp_mflags} DESTDIR=$RPM_BUILD_ROOT install

# fix the config
mv $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/pdns.conf-dist $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/pdns.conf

cat >> $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/pdns.conf << EOF
module-dir=%{_libdir}
socket-dir=/var/run/pdns-server
setuid=pdns
setgid=pdns
EOF

chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/pdns/pdns.conf

# install sysv scripts
install -d $RPM_BUILD_ROOT%{_initrddir}
install -m755 pdns/pdns $RPM_BUILD_ROOT%{_initrddir}/pdns

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%pre
if [ -z "`/usr/bin/id -g pdns 2>/dev/null`" ]; then
    /usr/sbin/groupadd -g 25 -r -f pdns 2>&1 || :
fi
if [ -z "`/usr/bin/id -u pdns 2>/dev/null`" ]; then
    /usr/sbin/useradd -u 25 -r -M -d /tmp  -s /sbin/nologin -c "PowerDNS" -g pdns pdns 2>&1 || :
fi

%post
/sbin/chkconfig --add pdns

%preun
if [ $1 -eq 0 ]; then
    /sbin/service pdns stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del pdns

    if [ -d /var/run/pdns-server ]; then
	rm -rf /var/run/pdns-server/*
    fi
fi

%postun
if [ $1 -eq 0 ]; then
    rm -rf %{_localstatedir}/run/pdns-server/
    /usr/sbin/userdel pdns 2>/dev/null || :
    /usr/sbin/groupdel pdns 2>/dev/null || :
fi

%files
%defattr(-,root,root)
"/usr/share/doc/pdns/*.sql"
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/pdns/pdns.conf
%config(noreplace) %attr(0755,root,root) %{_initrddir}/pdns
%dir %{_sysconfdir}/pdns
%dir %attr(0755,pdns,pdns) /var/run/pdns-server

%{_sbindir}/pdns_server

%{_bindir}/zone2ldap
%{_bindir}/zone2sql
%{_bindir}/pdns_control
%{_bindir}/pdnssec
%{_bindir}/zone2json

%{_mandir}/man1/pdns_control.1*
%{_mandir}/man1/pdns_server.1*
%{_mandir}/man1/zone2ldap.1*
%{_mandir}/man1/zone2sql.1*
%{_mandir}/man1/pdnssec.1*

%{_libdir}/pdns/libpipebackend.so
%{_libdir}/pdns/libpipebackend.la
%{_libdir}/pdns/libgmysqlbackend.la
%{_libdir}/pdns/libgeobackend.so
%{_libdir}/pdns/libgmysqlbackend.so
%{_libdir}/pdns/libgeobackend.la

%files tools
%defattr(-,root,root)
%{_bindir}/zone2json
%{_bindir}/zone2ldap
%{_bindir}/zone2sql

%files devel
%defattr(-,root,root)

%changelog
* Thu Apr 23 2015 Oliver Peter <oliver.peter@internetx.de>
- SlaveDB Patch remains as the only IX Patch
- Upgraded to PDNS 3.4.3

* Fri May 03 2013 Oliver Peter <oliver.peter@internetx.de>
- Added new allow-axfr-from patch (requires domainmetadata)
- Preparing to go live (RC1)

* Mon Sep 10 2012 Oliver Peter <oliver.peter@internetx.de> 3.1-2
- Applied SlaveDB Patch
- Pimped SPEC File (no dynamic modules, geobackend)

* Fri May 04 2012 Kees Monshouwer <km|monshouwer_com> 3.1-1
- Update to 3.1

* Sun Jan 08 2012 Kees Monshouwer <km|monshouwer_com> 3.0.1-1
- Update to 3.0.1

* Mon Jul 22 2011 Kees Monshouwer <km@monshouwer.com> 3.0-1
- Initial build for PowerDNS 3.0
